"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeSnapshotXSnapshotEncryptionKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_SELF_LINK_FIELD_NUMBER: builtins.int
    KMS_KEY_SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    RAW_KEY_FIELD_NUMBER: builtins.int
    SHA256_FIELD_NUMBER: builtins.int
    kms_key_self_link: builtins.str
    kms_key_service_account: builtins.str
    raw_key: builtins.str
    sha256: builtins.str
    def __init__(
        self,
        *,
        kms_key_self_link: builtins.str = ...,
        kms_key_service_account: builtins.str = ...,
        raw_key: builtins.str = ...,
        sha256: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_self_link", b"kms_key_self_link", "kms_key_service_account", b"kms_key_service_account", "raw_key", b"raw_key", "sha256", b"sha256"]) -> None: ...

global___ComputeSnapshotXSnapshotEncryptionKey = ComputeSnapshotXSnapshotEncryptionKey

@typing_extensions.final
class ComputeSnapshotXSourceDiskEncryptionKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    RAW_KEY_FIELD_NUMBER: builtins.int
    kms_key_service_account: builtins.str
    raw_key: builtins.str
    def __init__(
        self,
        *,
        kms_key_service_account: builtins.str = ...,
        raw_key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_service_account", b"kms_key_service_account", "raw_key", b"raw_key"]) -> None: ...

global___ComputeSnapshotXSourceDiskEncryptionKey = ComputeSnapshotXSourceDiskEncryptionKey

@typing_extensions.final
class ComputeSnapshotXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeSnapshotXTimeouts = ComputeSnapshotXTimeouts

@typing_extensions.final
class ComputeSnapshot(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABEL_FINGERPRINT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LICENSES_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SNAPSHOT_ID_FIELD_NUMBER: builtins.int
    SOURCE_DISK_FIELD_NUMBER: builtins.int
    STORAGE_BYTES_FIELD_NUMBER: builtins.int
    STORAGE_LOCATIONS_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    SNAPSHOT_ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    SOURCE_DISK_ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    disk_size_gb: builtins.float
    id: builtins.str
    label_fingerprint: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def licenses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    snapshot_id: builtins.float
    source_disk: builtins.str
    storage_bytes: builtins.float
    @property
    def storage_locations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    zone: builtins.str
    @property
    def snapshot_encryption_key(self) -> global___ComputeSnapshotXSnapshotEncryptionKey: ...
    @property
    def source_disk_encryption_key(self) -> global___ComputeSnapshotXSourceDiskEncryptionKey: ...
    @property
    def timeouts(self) -> global___ComputeSnapshotXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        disk_size_gb: builtins.float = ...,
        id: builtins.str = ...,
        label_fingerprint: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        licenses: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        snapshot_id: builtins.float = ...,
        source_disk: builtins.str = ...,
        storage_bytes: builtins.float = ...,
        storage_locations: collections.abc.Iterable[builtins.str] | None = ...,
        zone: builtins.str = ...,
        snapshot_encryption_key: global___ComputeSnapshotXSnapshotEncryptionKey | None = ...,
        source_disk_encryption_key: global___ComputeSnapshotXSourceDiskEncryptionKey | None = ...,
        timeouts: global___ComputeSnapshotXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "snapshot_encryption_key", b"snapshot_encryption_key", "source_disk_encryption_key", b"source_disk_encryption_key", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "description", b"description", "disk_size_gb", b"disk_size_gb", "id", b"id", "label_fingerprint", b"label_fingerprint", "labels", b"labels", "licenses", b"licenses", "name", b"name", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "snapshot_encryption_key", b"snapshot_encryption_key", "snapshot_id", b"snapshot_id", "source_disk", b"source_disk", "source_disk_encryption_key", b"source_disk_encryption_key", "storage_bytes", b"storage_bytes", "storage_locations", b"storage_locations", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputeSnapshot = ComputeSnapshot

@typing_extensions.final
class ComputeSnapshotIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ComputeSnapshotIamBindingXCondition = ComputeSnapshotIamBindingXCondition

@typing_extensions.final
class ComputeSnapshotIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    name: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___ComputeSnapshotIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___ComputeSnapshotIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "members", b"members", "name", b"name", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___ComputeSnapshotIamBinding = ComputeSnapshotIamBinding

@typing_extensions.final
class ComputeSnapshotIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___ComputeSnapshotIamMemberXCondition = ComputeSnapshotIamMemberXCondition

@typing_extensions.final
class ComputeSnapshotIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    member: builtins.str
    name: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___ComputeSnapshotIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        member: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___ComputeSnapshotIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["condition", b"condition", "etag", b"etag", "id", b"id", "member", b"member", "name", b"name", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___ComputeSnapshotIamMember = ComputeSnapshotIamMember

@typing_extensions.final
class ComputeSnapshotIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    etag: builtins.str
    id: builtins.str
    name: builtins.str
    policy_data: builtins.str
    project: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["etag", b"etag", "id", b"id", "name", b"name", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___ComputeSnapshotIamPolicy = ComputeSnapshotIamPolicy



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.api.core.v1_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Overhead(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PodFixedEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    POD_FIXED_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def pod_fixed(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        pod_fixed: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pod_fixed", b"pod_fixed", "resource_info", b"resource_info"]) -> None: ...

global___Overhead = Overhead

@typing_extensions.final
class RuntimeClass(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    HANDLER_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    OVERHEAD_FIELD_NUMBER: builtins.int
    SCHEDULING_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    handler: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def overhead(self) -> global___Overhead: ...
    @property
    def scheduling(self) -> global___Scheduling: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        handler: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        overhead: global___Overhead | None = ...,
        scheduling: global___Scheduling | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "overhead", b"overhead", "resource_info", b"resource_info", "scheduling", b"scheduling"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "handler", b"handler", "kind", b"kind", "metadata", b"metadata", "overhead", b"overhead", "resource_info", b"resource_info", "scheduling", b"scheduling"]) -> None: ...

global___RuntimeClass = RuntimeClass

@typing_extensions.final
class RuntimeClassList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RuntimeClass]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___RuntimeClass] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___RuntimeClassList = RuntimeClassList

@typing_extensions.final
class Scheduling(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class NodeSelectorEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    NODE_SELECTOR_FIELD_NUMBER: builtins.int
    TOLERATIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def node_selector(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def tolerations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Toleration]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        node_selector: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        tolerations: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.Toleration] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["node_selector", b"node_selector", "resource_info", b"resource_info", "tolerations", b"tolerations"]) -> None: ...

global___Scheduling = Scheduling



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class EventarcTriggerXDestinationXCloudRunService(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATH_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    path: builtins.str
    region: builtins.str
    service: builtins.str
    def __init__(
        self,
        *,
        path: builtins.str = ...,
        region: builtins.str = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["path", b"path", "region", b"region", "service", b"service"]) -> None: ...

global___EventarcTriggerXDestinationXCloudRunService = EventarcTriggerXDestinationXCloudRunService

@typing_extensions.final
class EventarcTriggerXDestinationXGke(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    cluster: builtins.str
    location: builtins.str
    namespace: builtins.str
    path: builtins.str
    service: builtins.str
    def __init__(
        self,
        *,
        cluster: builtins.str = ...,
        location: builtins.str = ...,
        namespace: builtins.str = ...,
        path: builtins.str = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster", b"cluster", "location", b"location", "namespace", b"namespace", "path", b"path", "service", b"service"]) -> None: ...

global___EventarcTriggerXDestinationXGke = EventarcTriggerXDestinationXGke

@typing_extensions.final
class EventarcTriggerXDestination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_FUNCTION_FIELD_NUMBER: builtins.int
    WORKFLOW_FIELD_NUMBER: builtins.int
    CLOUD_RUN_SERVICE_FIELD_NUMBER: builtins.int
    GKE_FIELD_NUMBER: builtins.int
    cloud_function: builtins.str
    workflow: builtins.str
    @property
    def cloud_run_service(self) -> global___EventarcTriggerXDestinationXCloudRunService: ...
    @property
    def gke(self) -> global___EventarcTriggerXDestinationXGke: ...
    def __init__(
        self,
        *,
        cloud_function: builtins.str = ...,
        workflow: builtins.str = ...,
        cloud_run_service: global___EventarcTriggerXDestinationXCloudRunService | None = ...,
        gke: global___EventarcTriggerXDestinationXGke | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cloud_run_service", b"cloud_run_service", "gke", b"gke"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_function", b"cloud_function", "cloud_run_service", b"cloud_run_service", "gke", b"gke", "workflow", b"workflow"]) -> None: ...

global___EventarcTriggerXDestination = EventarcTriggerXDestination

@typing_extensions.final
class EventarcTriggerXMatchingCriteria(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTRIBUTE_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    attribute: builtins.str
    operator: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        attribute: builtins.str = ...,
        operator: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute", b"attribute", "operator", b"operator", "value", b"value"]) -> None: ...

global___EventarcTriggerXMatchingCriteria = EventarcTriggerXMatchingCriteria

@typing_extensions.final
class EventarcTriggerXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___EventarcTriggerXTimeouts = EventarcTriggerXTimeouts

@typing_extensions.final
class EventarcTriggerXTransportXPubsub(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBSCRIPTION_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    subscription: builtins.str
    topic: builtins.str
    def __init__(
        self,
        *,
        subscription: builtins.str = ...,
        topic: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["subscription", b"subscription", "topic", b"topic"]) -> None: ...

global___EventarcTriggerXTransportXPubsub = EventarcTriggerXTransportXPubsub

@typing_extensions.final
class EventarcTriggerXTransport(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBSUB_FIELD_NUMBER: builtins.int
    @property
    def pubsub(self) -> global___EventarcTriggerXTransportXPubsub: ...
    def __init__(
        self,
        *,
        pubsub: global___EventarcTriggerXTransportXPubsub | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pubsub", b"pubsub"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pubsub", b"pubsub"]) -> None: ...

global___EventarcTriggerXTransport = EventarcTriggerXTransport

@typing_extensions.final
class EventarcTrigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    MATCHING_CRITERIA_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    TRANSPORT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    etag: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    service_account: builtins.str
    uid: builtins.str
    update_time: builtins.str
    @property
    def destination(self) -> global___EventarcTriggerXDestination: ...
    @property
    def matching_criteria(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EventarcTriggerXMatchingCriteria]: ...
    @property
    def timeouts(self) -> global___EventarcTriggerXTimeouts: ...
    @property
    def transport(self) -> global___EventarcTriggerXTransport: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        service_account: builtins.str = ...,
        uid: builtins.str = ...,
        update_time: builtins.str = ...,
        destination: global___EventarcTriggerXDestination | None = ...,
        matching_criteria: collections.abc.Iterable[global___EventarcTriggerXMatchingCriteria] | None = ...,
        timeouts: global___EventarcTriggerXTimeouts | None = ...,
        transport: global___EventarcTriggerXTransport | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["destination", b"destination", "resource_info", b"resource_info", "timeouts", b"timeouts", "transport", b"transport"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "destination", b"destination", "etag", b"etag", "id", b"id", "labels", b"labels", "location", b"location", "matching_criteria", b"matching_criteria", "name", b"name", "project", b"project", "resource_info", b"resource_info", "service_account", b"service_account", "timeouts", b"timeouts", "transport", b"transport", "uid", b"uid", "update_time", b"update_time"]) -> None: ...

global___EventarcTrigger = EventarcTrigger



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_network_routetables.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/azure/azure_microsoft_network_routetables.proto\x12/oak9.tython.azure.microsoft_network_routetables\x1a\x13shared/shared.proto\"\xd4\x01\n\x1dMicrosoft_Network_routeTables\x12R\n\x0croute_tables\x18\x01 \x01(\x0b\x32<.oak9.tython.azure.microsoft_network_routetables.RouteTables\x12_\n\x13route_tables_routes\x18\x02 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_network_routetables.RouteTablesRoutes\"\xc0\x01\n\x11RouteTablesRoutes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x61\x64\x64ress_prefix\x18\x03 \x01(\t\x12\x15\n\rnext_hop_type\x18\x04 \x01(\t\x12\x1b\n\x13next_hop_ip_address\x18\x05 \x01(\t\x12\x18\n\x10has_bgp_override\x18\x06 \x01(\x08\"\xd8\x02\n\x0bRouteTables\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12T\n\x04tags\x18\x04 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_network_routetables.RouteTables.TagsEntry\x12\x46\n\x06routes\x18\x05 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_network_routetables.Route\x12%\n\x1d\x64isable_bgp_route_propagation\x18\x06 \x01(\x08\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"{\n\x05Route\x12\x16\n\x0e\x61\x64\x64ress_prefix\x18\x01 \x01(\t\x12\x15\n\rnext_hop_type\x18\x02 \x01(\t\x12\x1b\n\x13next_hop_ip_address\x18\x03 \x01(\t\x12\x18\n\x10has_bgp_override\x18\x04 \x01(\x08\x12\x0c\n\x04name\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_network_routetables_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ROUTETABLES_TAGSENTRY._options = None
  _ROUTETABLES_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_NETWORK_ROUTETABLES._serialized_start=122
  _MICROSOFT_NETWORK_ROUTETABLES._serialized_end=334
  _ROUTETABLESROUTES._serialized_start=337
  _ROUTETABLESROUTES._serialized_end=529
  _ROUTETABLES._serialized_start=532
  _ROUTETABLES._serialized_end=876
  _ROUTETABLES_TAGSENTRY._serialized_start=833
  _ROUTETABLES_TAGSENTRY._serialized_end=876
  _ROUTE._serialized_start=878
  _ROUTE._serialized_end=1001
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.api.core.v1_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.api.resource_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CSIDriver(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___CSIDriverSpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___CSIDriverSpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> None: ...

global___CSIDriver = CSIDriver

@typing_extensions.final
class CSIDriverList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CSIDriver]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___CSIDriver] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___CSIDriverList = CSIDriverList

@typing_extensions.final
class CSIDriverSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTACH_REQUIRED_FIELD_NUMBER: builtins.int
    FS_GROUP_POLICY_FIELD_NUMBER: builtins.int
    POD_INFO_ON_MOUNT_FIELD_NUMBER: builtins.int
    REQUIRES_REPUBLISH_FIELD_NUMBER: builtins.int
    SE_LINUX_MOUNT_FIELD_NUMBER: builtins.int
    STORAGE_CAPACITY_FIELD_NUMBER: builtins.int
    TOKEN_REQUESTS_FIELD_NUMBER: builtins.int
    VOLUME_LIFECYCLE_MODES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    attach_required: builtins.bool
    fs_group_policy: builtins.str
    pod_info_on_mount: builtins.bool
    requires_republish: builtins.bool
    se_linux_mount: builtins.bool
    storage_capacity: builtins.bool
    @property
    def token_requests(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TokenRequest]: ...
    @property
    def volume_lifecycle_modes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        attach_required: builtins.bool = ...,
        fs_group_policy: builtins.str = ...,
        pod_info_on_mount: builtins.bool = ...,
        requires_republish: builtins.bool = ...,
        se_linux_mount: builtins.bool = ...,
        storage_capacity: builtins.bool = ...,
        token_requests: collections.abc.Iterable[global___TokenRequest] | None = ...,
        volume_lifecycle_modes: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attach_required", b"attach_required", "fs_group_policy", b"fs_group_policy", "pod_info_on_mount", b"pod_info_on_mount", "requires_republish", b"requires_republish", "resource_info", b"resource_info", "se_linux_mount", b"se_linux_mount", "storage_capacity", b"storage_capacity", "token_requests", b"token_requests", "volume_lifecycle_modes", b"volume_lifecycle_modes"]) -> None: ...

global___CSIDriverSpec = CSIDriverSpec

@typing_extensions.final
class CSINode(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___CSINodeSpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___CSINodeSpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> None: ...

global___CSINode = CSINode

@typing_extensions.final
class CSINodeDriver(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOCATABLE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NODE_ID_FIELD_NUMBER: builtins.int
    TOPOLOGY_KEYS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def allocatable(self) -> global___VolumeNodeResources: ...
    name: builtins.str
    node_id: builtins.str
    @property
    def topology_keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        allocatable: global___VolumeNodeResources | None = ...,
        name: builtins.str = ...,
        node_id: builtins.str = ...,
        topology_keys: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["allocatable", b"allocatable", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allocatable", b"allocatable", "name", b"name", "node_id", b"node_id", "resource_info", b"resource_info", "topology_keys", b"topology_keys"]) -> None: ...

global___CSINodeDriver = CSINodeDriver

@typing_extensions.final
class CSINodeList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CSINode]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___CSINode] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___CSINodeList = CSINodeList

@typing_extensions.final
class CSINodeSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DRIVERS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def drivers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CSINodeDriver]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        drivers: collections.abc.Iterable[global___CSINodeDriver] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["drivers", b"drivers", "resource_info", b"resource_info"]) -> None: ...

global___CSINodeSpec = CSINodeSpec

@typing_extensions.final
class CSIStorageCapacity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    CAPACITY_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    MAXIMUM_VOLUME_SIZE_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    NODE_TOPOLOGY_FIELD_NUMBER: builtins.int
    STORAGE_CLASS_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def capacity(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.api.resource_pb2.Quantity: ...
    kind: builtins.str
    @property
    def maximum_volume_size(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.api.resource_pb2.Quantity: ...
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def node_topology(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    storage_class_name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        capacity: kubernetes.kubernetes_io.k8s.apimachinery.pkg.api.resource_pb2.Quantity | None = ...,
        kind: builtins.str = ...,
        maximum_volume_size: kubernetes.kubernetes_io.k8s.apimachinery.pkg.api.resource_pb2.Quantity | None = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        node_topology: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        storage_class_name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "maximum_volume_size", b"maximum_volume_size", "metadata", b"metadata", "node_topology", b"node_topology", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "capacity", b"capacity", "kind", b"kind", "maximum_volume_size", b"maximum_volume_size", "metadata", b"metadata", "node_topology", b"node_topology", "resource_info", b"resource_info", "storage_class_name", b"storage_class_name"]) -> None: ...

global___CSIStorageCapacity = CSIStorageCapacity

@typing_extensions.final
class CSIStorageCapacityList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CSIStorageCapacity]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___CSIStorageCapacity] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___CSIStorageCapacityList = CSIStorageCapacityList

@typing_extensions.final
class StorageClass(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ParametersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ALLOW_VOLUME_EXPANSION_FIELD_NUMBER: builtins.int
    ALLOWED_TOPOLOGIES_FIELD_NUMBER: builtins.int
    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    MOUNT_OPTIONS_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    PROVISIONER_FIELD_NUMBER: builtins.int
    RECLAIM_POLICY_FIELD_NUMBER: builtins.int
    VOLUME_BINDING_MODE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    allow_volume_expansion: builtins.bool
    @property
    def allowed_topologies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.TopologySelectorTerm]: ...
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def mount_options(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def parameters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    provisioner: builtins.str
    reclaim_policy: builtins.str
    volume_binding_mode: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        allow_volume_expansion: builtins.bool = ...,
        allowed_topologies: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.TopologySelectorTerm] | None = ...,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        mount_options: collections.abc.Iterable[builtins.str] | None = ...,
        parameters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        provisioner: builtins.str = ...,
        reclaim_policy: builtins.str = ...,
        volume_binding_mode: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_volume_expansion", b"allow_volume_expansion", "allowed_topologies", b"allowed_topologies", "api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "mount_options", b"mount_options", "parameters", b"parameters", "provisioner", b"provisioner", "reclaim_policy", b"reclaim_policy", "resource_info", b"resource_info", "volume_binding_mode", b"volume_binding_mode"]) -> None: ...

global___StorageClass = StorageClass

@typing_extensions.final
class StorageClassList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StorageClass]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___StorageClass] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___StorageClassList = StorageClassList

@typing_extensions.final
class TokenRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIENCE_FIELD_NUMBER: builtins.int
    EXPIRATION_SECONDS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    audience: builtins.str
    expiration_seconds: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        audience: builtins.str = ...,
        expiration_seconds: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audience", b"audience", "expiration_seconds", b"expiration_seconds", "resource_info", b"resource_info"]) -> None: ...

global___TokenRequest = TokenRequest

@typing_extensions.final
class VolumeAttachment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___VolumeAttachmentSpec: ...
    @property
    def status(self) -> global___VolumeAttachmentStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___VolumeAttachmentSpec | None = ...,
        status: global___VolumeAttachmentStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___VolumeAttachment = VolumeAttachment

@typing_extensions.final
class VolumeAttachmentList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VolumeAttachment]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___VolumeAttachment] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___VolumeAttachmentList = VolumeAttachmentList

@typing_extensions.final
class VolumeAttachmentSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INLINE_VOLUME_SPEC_FIELD_NUMBER: builtins.int
    PERSISTENT_VOLUME_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def inline_volume_spec(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PersistentVolumeSpec: ...
    persistent_volume_name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        inline_volume_spec: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PersistentVolumeSpec | None = ...,
        persistent_volume_name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["inline_volume_spec", b"inline_volume_spec", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["inline_volume_spec", b"inline_volume_spec", "persistent_volume_name", b"persistent_volume_name", "resource_info", b"resource_info"]) -> None: ...

global___VolumeAttachmentSource = VolumeAttachmentSource

@typing_extensions.final
class VolumeAttachmentSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ATTACHER_FIELD_NUMBER: builtins.int
    NODE_NAME_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    attacher: builtins.str
    node_name: builtins.str
    @property
    def source(self) -> global___VolumeAttachmentSource: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        attacher: builtins.str = ...,
        node_name: builtins.str = ...,
        source: global___VolumeAttachmentSource | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "source", b"source"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attacher", b"attacher", "node_name", b"node_name", "resource_info", b"resource_info", "source", b"source"]) -> None: ...

global___VolumeAttachmentSpec = VolumeAttachmentSpec

@typing_extensions.final
class VolumeAttachmentStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AttachmentMetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ATTACH_ERROR_FIELD_NUMBER: builtins.int
    ATTACHED_FIELD_NUMBER: builtins.int
    ATTACHMENT_METADATA_FIELD_NUMBER: builtins.int
    DETACH_ERROR_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def attach_error(self) -> global___VolumeError: ...
    attached: builtins.bool
    @property
    def attachment_metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def detach_error(self) -> global___VolumeError: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        attach_error: global___VolumeError | None = ...,
        attached: builtins.bool = ...,
        attachment_metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        detach_error: global___VolumeError | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attach_error", b"attach_error", "detach_error", b"detach_error", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attach_error", b"attach_error", "attached", b"attached", "attachment_metadata", b"attachment_metadata", "detach_error", b"detach_error", "resource_info", b"resource_info"]) -> None: ...

global___VolumeAttachmentStatus = VolumeAttachmentStatus

@typing_extensions.final
class VolumeError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    message: builtins.str
    @property
    def time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        message: builtins.str = ...,
        time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "time", b"time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["message", b"message", "resource_info", b"resource_info", "time", b"time"]) -> None: ...

global___VolumeError = VolumeError

@typing_extensions.final
class VolumeNodeResources(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    count: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        count: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "resource_info", b"resource_info"]) -> None: ...

global___VolumeNodeResources = VolumeNodeResources



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class HttpNamespace(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___HttpNamespace = HttpNamespace

@typing_extensions.final
class ServiceDiscovery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HTTP_NAMESPACE_FIELD_NUMBER: builtins.int
    INSTANCE_FIELD_NUMBER: builtins.int
    PRIVATE_DNS_NAMESPACE_FIELD_NUMBER: builtins.int
    PUBLIC_DNS_NAMESPACE_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    @property
    def http_namespace(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HttpNamespace]: ...
    @property
    def instance(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Instance]: ...
    @property
    def private_dns_namespace(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivateDnsNamespace]: ...
    @property
    def public_dns_namespace(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PublicDnsNamespace]: ...
    @property
    def service(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Service]: ...
    def __init__(
        self,
        *,
        http_namespace: collections.abc.Iterable[global___HttpNamespace] | None = ...,
        instance: collections.abc.Iterable[global___Instance] | None = ...,
        private_dns_namespace: collections.abc.Iterable[global___PrivateDnsNamespace] | None = ...,
        public_dns_namespace: collections.abc.Iterable[global___PublicDnsNamespace] | None = ...,
        service: collections.abc.Iterable[global___Service] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["http_namespace", b"http_namespace", "instance", b"instance", "private_dns_namespace", b"private_dns_namespace", "public_dns_namespace", b"public_dns_namespace", "service", b"service"]) -> None: ...

global___ServiceDiscovery = ServiceDiscovery

@typing_extensions.final
class Instance(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class InstanceAttributesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INSTANCE_ATTRIBUTES_FIELD_NUMBER: builtins.int
    INSTANCE_ID_FIELD_NUMBER: builtins.int
    SERVICE_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def instance_attributes(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    instance_id: builtins.str
    service_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        instance_attributes: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        instance_id: builtins.str = ...,
        service_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["instance_attributes", b"instance_attributes", "instance_id", b"instance_id", "resource_info", b"resource_info", "service_id", b"service_id"]) -> None: ...

global___Instance = Instance

@typing_extensions.final
class PrivateDnsNamespace(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    VPC_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    vpc: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        vpc: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "resource_info", b"resource_info", "tags", b"tags", "vpc", b"vpc"]) -> None: ...

global___PrivateDnsNamespace = PrivateDnsNamespace

@typing_extensions.final
class PublicDnsNamespace(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___PublicDnsNamespace = PublicDnsNamespace

@typing_extensions.final
class ServiceHealthCheckCustomConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FAILURE_THRESHOLD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    failure_threshold: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        failure_threshold: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_threshold", b"failure_threshold", "resource_info", b"resource_info"]) -> None: ...

global___ServiceHealthCheckCustomConfig = ServiceHealthCheckCustomConfig

@typing_extensions.final
class ServiceDnsRecord(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TTL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    ttl: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ttl: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "ttl", b"ttl"]) -> None: ...

global___ServiceDnsRecord = ServiceDnsRecord

@typing_extensions.final
class ServiceDnsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DNS_RECORDS_FIELD_NUMBER: builtins.int
    ROUTING_POLICY_FIELD_NUMBER: builtins.int
    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def dns_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ServiceDnsRecord]: ...
    routing_policy: builtins.str
    namespace_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        dns_records: collections.abc.Iterable[global___ServiceDnsRecord] | None = ...,
        routing_policy: builtins.str = ...,
        namespace_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dns_records", b"dns_records", "namespace_id", b"namespace_id", "resource_info", b"resource_info", "routing_policy", b"routing_policy"]) -> None: ...

global___ServiceDnsConfig = ServiceDnsConfig

@typing_extensions.final
class ServiceHealthCheckConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCE_PATH_FIELD_NUMBER: builtins.int
    FAILURE_THRESHOLD_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    resource_path: builtins.str
    failure_threshold: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resource_path: builtins.str = ...,
        failure_threshold: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["failure_threshold", b"failure_threshold", "resource_info", b"resource_info", "resource_path", b"resource_path"]) -> None: ...

global___ServiceHealthCheckConfig = ServiceHealthCheckConfig

@typing_extensions.final
class Service(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_CUSTOM_CONFIG_FIELD_NUMBER: builtins.int
    DNS_CONFIG_FIELD_NUMBER: builtins.int
    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    HEALTH_CHECK_CONFIG_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def health_check_custom_config(self) -> global___ServiceHealthCheckCustomConfig: ...
    @property
    def dns_config(self) -> global___ServiceDnsConfig: ...
    namespace_id: builtins.str
    @property
    def health_check_config(self) -> global___ServiceHealthCheckConfig: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        health_check_custom_config: global___ServiceHealthCheckCustomConfig | None = ...,
        dns_config: global___ServiceDnsConfig | None = ...,
        namespace_id: builtins.str = ...,
        health_check_config: global___ServiceHealthCheckConfig | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dns_config", b"dns_config", "health_check_config", b"health_check_config", "health_check_custom_config", b"health_check_custom_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "dns_config", b"dns_config", "health_check_config", b"health_check_config", "health_check_custom_config", b"health_check_custom_config", "name", b"name", "namespace_id", b"namespace_id", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Service = Service



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_filestore.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gcp/gcp_filestore.proto\x12\x19oak9.tython.gcp.filestore\x1a\x13shared/shared.proto\"\x90\x01\n-FilestoreInstanceXFileSharesXNfsExportOptions\x12\x13\n\x0b\x61\x63\x63\x65ss_mode\x18\x01 \x01(\t\x12\x10\n\x08\x61non_gid\x18\x02 \x01(\x01\x12\x10\n\x08\x61non_uid\x18\x03 \x01(\x01\x12\x11\n\tip_ranges\x18\x04 \x03(\t\x12\x13\n\x0bsquash_mode\x18\x05 \x01(\t\"\xa7\x01\n\x1c\x46ilestoreInstanceXFileShares\x12\x13\n\x0b\x63\x61pacity_gb\x18\x01 \x01(\x01\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x64\n\x12nfs_export_options\x18\x03 \x03(\x0b\x32H.oak9.tython.gcp.filestore.FilestoreInstanceXFileSharesXNfsExportOptions\"\x83\x01\n\x1a\x46ilestoreInstanceXNetworks\x12\x14\n\x0c\x63onnect_mode\x18\x01 \x01(\t\x12\x14\n\x0cip_addresses\x18\x02 \x03(\t\x12\r\n\x05modes\x18\x03 \x03(\t\x12\x0f\n\x07network\x18\x04 \x01(\t\x12\x19\n\x11reserved_ip_range\x18\x05 \x01(\t\"L\n\x1a\x46ilestoreInstanceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xcc\x04\n\x11\x46ilestoreInstance\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04\x65tag\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x14\n\x0ckms_key_name\x18\x05 \x01(\t\x12H\n\x06labels\x18\x06 \x03(\x0b\x32\x38.oak9.tython.gcp.filestore.FilestoreInstance.LabelsEntry\x12\x10\n\x08location\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\x12\x0c\n\x04tier\x18\n \x01(\t\x12\x0c\n\x04zone\x18\x0b \x01(\t\x12L\n\x0b\x66ile_shares\x18\x0c \x01(\x0b\x32\x37.oak9.tython.gcp.filestore.FilestoreInstanceXFileShares\x12G\n\x08networks\x18\r \x03(\x0b\x32\x35.oak9.tython.gcp.filestore.FilestoreInstanceXNetworks\x12G\n\x08timeouts\x18\x0e \x01(\x0b\x32\x35.oak9.tython.gcp.filestore.FilestoreInstanceXTimeouts\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_filestore_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FILESTOREINSTANCE_LABELSENTRY._options = None
  _FILESTOREINSTANCE_LABELSENTRY._serialized_options = b'8\001'
  _FILESTOREINSTANCEXFILESHARESXNFSEXPORTOPTIONS._serialized_start=76
  _FILESTOREINSTANCEXFILESHARESXNFSEXPORTOPTIONS._serialized_end=220
  _FILESTOREINSTANCEXFILESHARES._serialized_start=223
  _FILESTOREINSTANCEXFILESHARES._serialized_end=390
  _FILESTOREINSTANCEXNETWORKS._serialized_start=393
  _FILESTOREINSTANCEXNETWORKS._serialized_end=524
  _FILESTOREINSTANCEXTIMEOUTS._serialized_start=526
  _FILESTOREINSTANCEXTIMEOUTS._serialized_end=602
  _FILESTOREINSTANCE._serialized_start=605
  _FILESTOREINSTANCE._serialized_end=1193
  _FILESTOREINSTANCE_LABELSENTRY._serialized_start=1148
  _FILESTOREINSTANCE_LABELSENTRY._serialized_end=1193
# @@protoc_insertion_point(module_scope)



"""Module providingFunction utilities for the runner."""
import json
from typing import List
from core.tools import get_config_id
from policyuniverse.policy import Policy
from policyuniverse.statement import Statement


def has_IP_Match_Rule(AzureWAF):
    if not len(AzureWAF.custom_rules) > 0:
        return False
    
    else:
        count = 0
        for rule in AzureWAF.custom_rules:
            if len(rule.match_conditions) > 0:
                for condition in rule.match_conditions:
                    if condition.operator.lower() == 'ipmatch':
                        count = count +1
        
        return False if count == 0 else True


def has_Geo_Match_Rule(AzureWAF):
    if not len(AzureWAF.custom_rules) > 0:
        return False
    
    else:
        count = 0
        for rule in AzureWAF.custom_rules:
            if len(rule.match_conditions) > 0:
                for condition in rule.match_conditions:
                    if condition.operator.lower() == 'geomatch':
                        count = count +1
        
        return False if count == 0 else True


def has_Managed_Rule_Set(AzureWAF, rulesetname):
    if not len(AzureWAF.managed_rules.managed_rule_sets) > 0:
        return False
    
    else:
        count = 0
        for rule_set in AzureWAF.managed_rules.managed_rule_sets:
            if rule_set.rule_set_type.__contains__(rulesetname):
                count = count + 1

        if count == 0:
            return False
        
        else:
            return True


def has_Managed_Rule_Set_Overrides(AzureWAF, rulesetname):
    if not len(AzureWAF.managed_rules.managed_rule_sets) > 0:
        return True
    
    else:
        count = 0
        for rule_set in AzureWAF.managed_rules.managed_rule_sets:
            if rule_set.rule_set_type.__contains__(rulesetname) and len(rule_set.rule_group_overrides) > 0:
                count = count+1
                
        if count == 0:
            return False
        
        else:
            return True


def has_Rate_Limit_Rule(AzureWAF):
    if not len(AzureWAF.custom_rules) > 0:
        return False
    
    else:
        count = 0
        for rule in AzureWAF.custom_rules:
            if rule.rule_type == 'RateLimitRule':
                count = count +1
        
        return False if count == 0 else True


def get_aws_json_policy(json_object: str):

    try:
        
        policy = json.loads(json_object.replace("\n;", ""))
        policy = Policy(policy)
        
    except Exception as e:
        
        # failed to generate json and create policy object
        return None

    if policy:
        return policy
    else:
        return None


def check_aws_policy_action(statement: Statement, insecure_actions: list[str]) -> List[str]:
    """_summary_
        This method will check the statement of a policy for the action(s) specified

    Args:
        statement (Statement): The policy statement to be evaluated 
        actions (list[str]): The list of insecure actions 

    Returns:
       insecure_actions_found (list[str]): The insecure actions found within the statement
       
    """
    
    insecure_actions_found: list[str] = []
    
    if statement.effect.lower() == "allow":
        
        for insecure_action in insecure_actions:
            if insecure_action in statement.actions:
                 
                insecure_actions_found.append(insecure_action)

    return insecure_actions_found


def check_aws_policy_resource(statement: Statement, insecure_resources: list[str]) -> List[str]:
    
    """_summary_
    This method will check the statement of a policy for the resource(s) specified
    
    Args:
        statement (Statement): The policy statement to be evaluated 
        resources (list[str]): The list of insecure resources

    Returns:
       insecure_resource_found (list[str]): The insecure actions found within the statement
    """
    
    insecure_resource_found: list[str] = []
    
    if statement.effect.lower() == "allow":
            
        for insecure_resource in insecure_resources:
            if insecure_resource in statement.resources:
                 
                insecure_resource_found.append(insecure_resource)
    
    return insecure_resource_found


def check_aws_policy_principal(statement: Statement, insecure_principals: list[str]) -> List[str]:
    
    """_summary_
    This method will check the statement of a policy for the principal(s) specified
    
    Args:
        statement (Statement): The policy statement to be evaluated
        principal (list[str]): The list of insecure principals

    Returns:
    
       insecure_principal_found (list[str]): The insecure principals found within the statement
    """
    
    insecure_principal_found: list[str] = []
    
    if statement.effect.lower() == "allow":
            
        for insecure_principal in insecure_principals:
            if insecure_principal in statement.principals:
                 
                insecure_principal_found.append(insecure_principal)
        
    return insecure_principal_found

def azure_keyvault_policies_are_defined(keyvault):
    config_list = []
    obj_list = []
    is_defined: bool = False    

    if len(keyvault.vaults_access_policies) > 0:
        obj_list.append(keyvault.vaults_access_policies)
        config_list.append(get_config_id(keyvault, 'vaults_access_policies', keyvault))
        is_defined = True
    if len(keyvault.vaults.access_policies) > 0:
        obj_list.append([keyvault.vaults])
        config_list.append(get_config_id(keyvault, 'access_policies', keyvault.vaults))
        is_defined = True
    if not (len(keyvault.vaults_access_policies) > 0 or len(keyvault.vaults.access_policies) > 0):
        config_list.append(get_config_id(keyvault, 'vaults_access_policies', keyvault))

    return (is_defined, config_list, obj_list)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_app_engine_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_app_pb2 as gcp_dot_gcp__app__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&gcp/gcp_google_app_engine_bundle.proto\x12(oak9.tython.gcp.google_app_engine_bundle\x1a\x13shared/shared.proto\x1a\x11gcp/gcp_app.proto\"\xde\x05\n\x0fGoogleAppEngine\x12I\n\x16\x61pp_engine_application\x18\x01 \x01(\x0b\x32).oak9.tython.gcp.app.AppEngineApplication\x12l\n)app_engine_application_url_dispatch_rules\x18\x02 \x03(\x0b\x32\x39.oak9.tython.gcp.app.AppEngineApplicationUrlDispatchRules\x12N\n\x19\x61pp_engine_domain_mapping\x18\x03 \x03(\x0b\x32+.oak9.tython.gcp.app.AppEngineDomainMapping\x12L\n\x18\x61pp_engine_firewall_rule\x18\x04 \x03(\x0b\x32*.oak9.tython.gcp.app.AppEngineFirewallRule\x12Y\n\x1f\x61pp_engine_flexible_app_version\x18\x05 \x03(\x0b\x32\x30.oak9.tython.gcp.app.AppEngineFlexibleAppVersion\x12\x61\n#app_engine_service_network_settings\x18\x06 \x03(\x0b\x32\x34.oak9.tython.gcp.app.AppEngineServiceNetworkSettings\x12[\n app_engine_service_split_traffic\x18\x07 \x03(\x0b\x32\x31.oak9.tython.gcp.app.AppEngineServiceSplitTraffic\x12Y\n\x1f\x61pp_engine_standard_app_version\x18\x08 \x03(\x0b\x32\x30.oak9.tython.gcp.app.AppEngineStandardAppVersionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_app_engine_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLEAPPENGINE._serialized_start=125
  _GOOGLEAPPENGINE._serialized_end=859
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AliasProvisionedConcurrencyConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PROVISIONED_CONCURRENT_EXECUTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    provisioned_concurrent_executions: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        provisioned_concurrent_executions: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["provisioned_concurrent_executions", b"provisioned_concurrent_executions", "resource_info", b"resource_info"]) -> None: ...

global___AliasProvisionedConcurrencyConfiguration = AliasProvisionedConcurrencyConfiguration

@typing_extensions.final
class AliasVersionWeight(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FUNCTION_VERSION_FIELD_NUMBER: builtins.int
    FUNCTION_WEIGHT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    function_version: builtins.str
    function_weight: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        function_version: builtins.str = ...,
        function_weight: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["function_version", b"function_version", "function_weight", b"function_weight", "resource_info", b"resource_info"]) -> None: ...

global___AliasVersionWeight = AliasVersionWeight

@typing_extensions.final
class AliasAliasRoutingConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ADDITIONAL_VERSION_WEIGHTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def additional_version_weights(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AliasVersionWeight]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        additional_version_weights: collections.abc.Iterable[global___AliasVersionWeight] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_version_weights", b"additional_version_weights", "resource_info", b"resource_info"]) -> None: ...

global___AliasAliasRoutingConfiguration = AliasAliasRoutingConfiguration

@typing_extensions.final
class Alias(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FUNCTION_NAME_FIELD_NUMBER: builtins.int
    FUNCTION_VERSION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROVISIONED_CONCURRENCY_CONFIG_FIELD_NUMBER: builtins.int
    ROUTING_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    function_name: builtins.str
    function_version: builtins.str
    name: builtins.str
    @property
    def provisioned_concurrency_config(self) -> global___AliasProvisionedConcurrencyConfiguration: ...
    @property
    def routing_config(self) -> global___AliasAliasRoutingConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        function_name: builtins.str = ...,
        function_version: builtins.str = ...,
        name: builtins.str = ...,
        provisioned_concurrency_config: global___AliasProvisionedConcurrencyConfiguration | None = ...,
        routing_config: global___AliasAliasRoutingConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provisioned_concurrency_config", b"provisioned_concurrency_config", "resource_info", b"resource_info", "routing_config", b"routing_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "function_name", b"function_name", "function_version", b"function_version", "name", b"name", "provisioned_concurrency_config", b"provisioned_concurrency_config", "resource_info", b"resource_info", "routing_config", b"routing_config"]) -> None: ...

global___Alias = Alias

@typing_extensions.final
class Lambda(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALIAS_FIELD_NUMBER: builtins.int
    EVENT_INVOKE_CONFIG_FIELD_NUMBER: builtins.int
    EVENT_SOURCE_MAPPING_FIELD_NUMBER: builtins.int
    FUNCTION_FIELD_NUMBER: builtins.int
    LAYER_VERSION_FIELD_NUMBER: builtins.int
    LAYER_VERSION_PERMISSION_FIELD_NUMBER: builtins.int
    PERMISSION_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def alias(self) -> global___Alias: ...
    @property
    def event_invoke_config(self) -> global___EventInvokeConfig: ...
    @property
    def event_source_mapping(self) -> global___EventSourceMapping: ...
    @property
    def function(self) -> global___Function: ...
    @property
    def layer_version(self) -> global___LayerVersion: ...
    @property
    def layer_version_permission(self) -> global___LayerVersionPermission: ...
    @property
    def permission(self) -> global___Permission: ...
    @property
    def version(self) -> global___Version: ...
    def __init__(
        self,
        *,
        alias: global___Alias | None = ...,
        event_invoke_config: global___EventInvokeConfig | None = ...,
        event_source_mapping: global___EventSourceMapping | None = ...,
        function: global___Function | None = ...,
        layer_version: global___LayerVersion | None = ...,
        layer_version_permission: global___LayerVersionPermission | None = ...,
        permission: global___Permission | None = ...,
        version: global___Version | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["alias", b"alias", "event_invoke_config", b"event_invoke_config", "event_source_mapping", b"event_source_mapping", "function", b"function", "layer_version", b"layer_version", "layer_version_permission", b"layer_version_permission", "permission", b"permission", "version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alias", b"alias", "event_invoke_config", b"event_invoke_config", "event_source_mapping", b"event_source_mapping", "function", b"function", "layer_version", b"layer_version", "layer_version_permission", b"layer_version_permission", "permission", b"permission", "version", b"version"]) -> None: ...

global___Lambda = Lambda

@typing_extensions.final
class EventInvokeConfigOnSuccess(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    destination: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        destination: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination", b"destination", "resource_info", b"resource_info"]) -> None: ...

global___EventInvokeConfigOnSuccess = EventInvokeConfigOnSuccess

@typing_extensions.final
class EventInvokeConfigOnFailure(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    destination: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        destination: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination", b"destination", "resource_info", b"resource_info"]) -> None: ...

global___EventInvokeConfigOnFailure = EventInvokeConfigOnFailure

@typing_extensions.final
class EventInvokeConfigDestinationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ON_SUCCESS_FIELD_NUMBER: builtins.int
    ON_FAILURE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def on_success(self) -> global___EventInvokeConfigOnSuccess: ...
    @property
    def on_failure(self) -> global___EventInvokeConfigOnFailure: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        on_success: global___EventInvokeConfigOnSuccess | None = ...,
        on_failure: global___EventInvokeConfigOnFailure | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["on_failure", b"on_failure", "on_success", b"on_success", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["on_failure", b"on_failure", "on_success", b"on_success", "resource_info", b"resource_info"]) -> None: ...

global___EventInvokeConfigDestinationConfig = EventInvokeConfigDestinationConfig

@typing_extensions.final
class EventInvokeConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FUNCTION_NAME_FIELD_NUMBER: builtins.int
    MAXIMUM_RETRY_ATTEMPTS_FIELD_NUMBER: builtins.int
    DESTINATION_CONFIG_FIELD_NUMBER: builtins.int
    QUALIFIER_FIELD_NUMBER: builtins.int
    MAXIMUM_EVENT_AGE_IN_SECONDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    function_name: builtins.str
    maximum_retry_attempts: builtins.int
    @property
    def destination_config(self) -> global___EventInvokeConfigDestinationConfig: ...
    qualifier: builtins.str
    maximum_event_age_in_seconds: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        function_name: builtins.str = ...,
        maximum_retry_attempts: builtins.int = ...,
        destination_config: global___EventInvokeConfigDestinationConfig | None = ...,
        qualifier: builtins.str = ...,
        maximum_event_age_in_seconds: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["destination_config", b"destination_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination_config", b"destination_config", "function_name", b"function_name", "maximum_event_age_in_seconds", b"maximum_event_age_in_seconds", "maximum_retry_attempts", b"maximum_retry_attempts", "qualifier", b"qualifier", "resource_info", b"resource_info"]) -> None: ...

global___EventInvokeConfig = EventInvokeConfig

@typing_extensions.final
class EventSourceMappingOnFailure(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    destination: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        destination: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination", b"destination", "resource_info", b"resource_info"]) -> None: ...

global___EventSourceMappingOnFailure = EventSourceMappingOnFailure

@typing_extensions.final
class EventSourceMappingDestinationConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ON_FAILURE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def on_failure(self) -> global___EventSourceMappingOnFailure: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        on_failure: global___EventSourceMappingOnFailure | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["on_failure", b"on_failure", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["on_failure", b"on_failure", "resource_info", b"resource_info"]) -> None: ...

global___EventSourceMappingDestinationConfig = EventSourceMappingDestinationConfig

@typing_extensions.final
class EventSourceMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BATCH_SIZE_FIELD_NUMBER: builtins.int
    BISECT_BATCH_ON_FUNCTION_ERROR_FIELD_NUMBER: builtins.int
    DESTINATION_CONFIG_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    EVENT_SOURCE_ARN_FIELD_NUMBER: builtins.int
    FUNCTION_NAME_FIELD_NUMBER: builtins.int
    MAXIMUM_BATCHING_WINDOW_IN_SECONDS_FIELD_NUMBER: builtins.int
    MAXIMUM_RECORD_AGE_IN_SECONDS_FIELD_NUMBER: builtins.int
    MAXIMUM_RETRY_ATTEMPTS_FIELD_NUMBER: builtins.int
    PARALLELIZATION_FACTOR_FIELD_NUMBER: builtins.int
    STARTING_POSITION_FIELD_NUMBER: builtins.int
    TOPICS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    batch_size: builtins.int
    bisect_batch_on_function_error: builtins.bool
    @property
    def destination_config(self) -> global___EventSourceMappingDestinationConfig: ...
    enabled: builtins.bool
    event_source_arn: builtins.str
    function_name: builtins.str
    maximum_batching_window_in_seconds: builtins.int
    maximum_record_age_in_seconds: builtins.int
    maximum_retry_attempts: builtins.int
    parallelization_factor: builtins.int
    starting_position: builtins.str
    @property
    def topics(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        batch_size: builtins.int = ...,
        bisect_batch_on_function_error: builtins.bool = ...,
        destination_config: global___EventSourceMappingDestinationConfig | None = ...,
        enabled: builtins.bool = ...,
        event_source_arn: builtins.str = ...,
        function_name: builtins.str = ...,
        maximum_batching_window_in_seconds: builtins.int = ...,
        maximum_record_age_in_seconds: builtins.int = ...,
        maximum_retry_attempts: builtins.int = ...,
        parallelization_factor: builtins.int = ...,
        starting_position: builtins.str = ...,
        topics: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["destination_config", b"destination_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_size", b"batch_size", "bisect_batch_on_function_error", b"bisect_batch_on_function_error", "destination_config", b"destination_config", "enabled", b"enabled", "event_source_arn", b"event_source_arn", "function_name", b"function_name", "maximum_batching_window_in_seconds", b"maximum_batching_window_in_seconds", "maximum_record_age_in_seconds", b"maximum_record_age_in_seconds", "maximum_retry_attempts", b"maximum_retry_attempts", "parallelization_factor", b"parallelization_factor", "resource_info", b"resource_info", "starting_position", b"starting_position", "topics", b"topics"]) -> None: ...

global___EventSourceMapping = EventSourceMapping

@typing_extensions.final
class FunctionCode(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_BUCKET_FIELD_NUMBER: builtins.int
    S3_KEY_FIELD_NUMBER: builtins.int
    S3_OBJECT_VERSION_FIELD_NUMBER: builtins.int
    ZIP_FILE_FIELD_NUMBER: builtins.int
    IMAGE_URI_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    s3_bucket: builtins.str
    s3_key: builtins.str
    s3_object_version: builtins.str
    zip_file: builtins.str
    image_uri: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_bucket: builtins.str = ...,
        s3_key: builtins.str = ...,
        s3_object_version: builtins.str = ...,
        zip_file: builtins.str = ...,
        image_uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["image_uri", b"image_uri", "resource_info", b"resource_info", "s3_bucket", b"s3_bucket", "s3_key", b"s3_key", "s3_object_version", b"s3_object_version", "zip_file", b"zip_file"]) -> None: ...

global___FunctionCode = FunctionCode

@typing_extensions.final
class FunctionDeadLetterConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TARGET_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    target_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        target_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "target_arn", b"target_arn"]) -> None: ...

global___FunctionDeadLetterConfig = FunctionDeadLetterConfig

@typing_extensions.final
class FunctionEnvironment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class VariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VARIABLES_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    error: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        error: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["error", b"error", "resource_info", b"resource_info", "variables", b"variables"]) -> None: ...

global___FunctionEnvironment = FunctionEnvironment

@typing_extensions.final
class FunctionFileSystemConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ARN_FIELD_NUMBER: builtins.int
    LOCAL_MOUNT_PATH_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    arn: builtins.str
    local_mount_path: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        arn: builtins.str = ...,
        local_mount_path: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["arn", b"arn", "local_mount_path", b"local_mount_path", "resource_info", b"resource_info"]) -> None: ...

global___FunctionFileSystemConfig = FunctionFileSystemConfig

@typing_extensions.final
class FunctionTracingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    mode: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        mode: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["mode", b"mode", "resource_info", b"resource_info"]) -> None: ...

global___FunctionTracingConfig = FunctionTracingConfig

@typing_extensions.final
class FunctionVpcConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    vpc_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        vpc_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "security_group_ids", b"security_group_ids", "subnet_ids", b"subnet_ids", "vpc_id", b"vpc_id"]) -> None: ...

global___FunctionVpcConfig = FunctionVpcConfig

@typing_extensions.final
class Function(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    DEAD_LETTER_CONFIG_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    FILE_SYSTEM_CONFIGS_FIELD_NUMBER: builtins.int
    FUNCTION_NAME_FIELD_NUMBER: builtins.int
    HANDLER_FIELD_NUMBER: builtins.int
    KMS_KEY_ARN_FIELD_NUMBER: builtins.int
    LAYERS_FIELD_NUMBER: builtins.int
    MEMORY_SIZE_FIELD_NUMBER: builtins.int
    RESERVED_CONCURRENT_EXECUTIONS_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    RUNTIME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    TRACING_CONFIG_FIELD_NUMBER: builtins.int
    VPC_CONFIG_FIELD_NUMBER: builtins.int
    REVISION_ID_FIELD_NUMBER: builtins.int
    MASTER_ARN_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_FIELD_NUMBER: builtins.int
    CODE_SIZE_FIELD_NUMBER: builtins.int
    CODE_SHA256_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def code(self) -> global___FunctionCode: ...
    @property
    def dead_letter_config(self) -> global___FunctionDeadLetterConfig: ...
    description: builtins.str
    @property
    def environment(self) -> global___FunctionEnvironment: ...
    @property
    def file_system_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FunctionFileSystemConfig]: ...
    function_name: builtins.str
    handler: builtins.str
    kms_key_arn: builtins.str
    @property
    def layers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    memory_size: builtins.int
    reserved_concurrent_executions: builtins.int
    role: builtins.str
    runtime: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    timeout: builtins.int
    @property
    def tracing_config(self) -> global___FunctionTracingConfig: ...
    @property
    def vpc_config(self) -> global___FunctionVpcConfig: ...
    revision_id: builtins.str
    master_arn: builtins.str
    version: builtins.str
    last_modified: builtins.str
    code_size: builtins.str
    code_sha256: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        code: global___FunctionCode | None = ...,
        dead_letter_config: global___FunctionDeadLetterConfig | None = ...,
        description: builtins.str = ...,
        environment: global___FunctionEnvironment | None = ...,
        file_system_configs: collections.abc.Iterable[global___FunctionFileSystemConfig] | None = ...,
        function_name: builtins.str = ...,
        handler: builtins.str = ...,
        kms_key_arn: builtins.str = ...,
        layers: collections.abc.Iterable[builtins.str] | None = ...,
        memory_size: builtins.int = ...,
        reserved_concurrent_executions: builtins.int = ...,
        role: builtins.str = ...,
        runtime: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        timeout: builtins.int = ...,
        tracing_config: global___FunctionTracingConfig | None = ...,
        vpc_config: global___FunctionVpcConfig | None = ...,
        revision_id: builtins.str = ...,
        master_arn: builtins.str = ...,
        version: builtins.str = ...,
        last_modified: builtins.str = ...,
        code_size: builtins.str = ...,
        code_sha256: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["code", b"code", "dead_letter_config", b"dead_letter_config", "environment", b"environment", "resource_info", b"resource_info", "tracing_config", b"tracing_config", "vpc_config", b"vpc_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "code_sha256", b"code_sha256", "code_size", b"code_size", "dead_letter_config", b"dead_letter_config", "description", b"description", "environment", b"environment", "file_system_configs", b"file_system_configs", "function_name", b"function_name", "handler", b"handler", "kms_key_arn", b"kms_key_arn", "last_modified", b"last_modified", "layers", b"layers", "master_arn", b"master_arn", "memory_size", b"memory_size", "reserved_concurrent_executions", b"reserved_concurrent_executions", "resource_info", b"resource_info", "revision_id", b"revision_id", "role", b"role", "runtime", b"runtime", "tags", b"tags", "timeout", b"timeout", "tracing_config", b"tracing_config", "version", b"version", "vpc_config", b"vpc_config"]) -> None: ...

global___Function = Function

@typing_extensions.final
class LayerVersionContent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_OBJECT_VERSION_FIELD_NUMBER: builtins.int
    S3_BUCKET_FIELD_NUMBER: builtins.int
    S3_KEY_FIELD_NUMBER: builtins.int
    CODE_SHA256_FIELD_NUMBER: builtins.int
    CODE_SIZE_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    s3_object_version: builtins.str
    s3_bucket: builtins.str
    s3_key: builtins.str
    code_sha256: builtins.str
    code_size: builtins.str
    location: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_object_version: builtins.str = ...,
        s3_bucket: builtins.str = ...,
        s3_key: builtins.str = ...,
        code_sha256: builtins.str = ...,
        code_size: builtins.str = ...,
        location: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["code_sha256", b"code_sha256", "code_size", b"code_size", "location", b"location", "resource_info", b"resource_info", "s3_bucket", b"s3_bucket", "s3_key", b"s3_key", "s3_object_version", b"s3_object_version"]) -> None: ...

global___LayerVersionContent = LayerVersionContent

@typing_extensions.final
class LayerVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMPATIBLE_RUNTIMES_FIELD_NUMBER: builtins.int
    LICENSE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LAYER_NAME_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    LAYER_ARN_FIELD_NUMBER: builtins.int
    LAYER_VERSION_ARN_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    CREATED_DATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def compatible_runtimes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    license_info: builtins.str
    description: builtins.str
    layer_name: builtins.str
    @property
    def content(self) -> global___LayerVersionContent: ...
    layer_arn: builtins.str
    layer_version_arn: builtins.str
    version: builtins.str
    created_date: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        compatible_runtimes: collections.abc.Iterable[builtins.str] | None = ...,
        license_info: builtins.str = ...,
        description: builtins.str = ...,
        layer_name: builtins.str = ...,
        content: global___LayerVersionContent | None = ...,
        layer_arn: builtins.str = ...,
        layer_version_arn: builtins.str = ...,
        version: builtins.str = ...,
        created_date: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compatible_runtimes", b"compatible_runtimes", "content", b"content", "created_date", b"created_date", "description", b"description", "layer_arn", b"layer_arn", "layer_name", b"layer_name", "layer_version_arn", b"layer_version_arn", "license_info", b"license_info", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___LayerVersion = LayerVersion

@typing_extensions.final
class LayerVersionPermission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    LAYER_VERSION_ARN_FIELD_NUMBER: builtins.int
    ORGANIZATION_ID_FIELD_NUMBER: builtins.int
    PRINCIPAL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    action: builtins.str
    layer_version_arn: builtins.str
    organization_id: builtins.str
    principal: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        action: builtins.str = ...,
        layer_version_arn: builtins.str = ...,
        organization_id: builtins.str = ...,
        principal: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "layer_version_arn", b"layer_version_arn", "organization_id", b"organization_id", "principal", b"principal", "resource_info", b"resource_info"]) -> None: ...

global___LayerVersionPermission = LayerVersionPermission

@typing_extensions.final
class Permission(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    EVENT_SOURCE_TOKEN_FIELD_NUMBER: builtins.int
    FUNCTION_NAME_FIELD_NUMBER: builtins.int
    PRINCIPAL_FIELD_NUMBER: builtins.int
    SOURCE_ACCOUNT_FIELD_NUMBER: builtins.int
    SOURCE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    action: builtins.str
    event_source_token: builtins.str
    function_name: builtins.str
    principal: builtins.str
    source_account: builtins.str
    source_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        action: builtins.str = ...,
        event_source_token: builtins.str = ...,
        function_name: builtins.str = ...,
        principal: builtins.str = ...,
        source_account: builtins.str = ...,
        source_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "event_source_token", b"event_source_token", "function_name", b"function_name", "principal", b"principal", "resource_info", b"resource_info", "source_account", b"source_account", "source_arn", b"source_arn"]) -> None: ...

global___Permission = Permission

@typing_extensions.final
class VersionProvisionedConcurrencyConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PROVISIONED_CONCURRENT_EXECUTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    provisioned_concurrent_executions: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        provisioned_concurrent_executions: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["provisioned_concurrent_executions", b"provisioned_concurrent_executions", "resource_info", b"resource_info"]) -> None: ...

global___VersionProvisionedConcurrencyConfiguration = VersionProvisionedConcurrencyConfiguration

@typing_extensions.final
class Version(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CODE_SHA256_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FUNCTION_NAME_FIELD_NUMBER: builtins.int
    PROVISIONED_CONCURRENCY_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    code_sha256: builtins.str
    description: builtins.str
    function_name: builtins.str
    @property
    def provisioned_concurrency_config(self) -> global___VersionProvisionedConcurrencyConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        code_sha256: builtins.str = ...,
        description: builtins.str = ...,
        function_name: builtins.str = ...,
        provisioned_concurrency_config: global___VersionProvisionedConcurrencyConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provisioned_concurrency_config", b"provisioned_concurrency_config", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["code_sha256", b"code_sha256", "description", b"description", "function_name", b"function_name", "provisioned_concurrency_config", b"provisioned_concurrency_config", "resource_info", b"resource_info"]) -> None: ...

global___Version = Version
